'use strict';

var react = require('react');
var usehooksTs = require('usehooks-ts');

var useLoadScript = function (_a) {
  var script = _a.script;
  var status = usehooksTs.useScript(script);
  var _b = react.useState(false),
    init = _b[0],
    setInit = _b[1];
  react.useEffect(function () {
    if (status !== "ready") return;
    setInit(true);
  }, [status]);
  return {
    init: init
  };
};

var MANIFEST_SCRIPT = 'https://bridge.usemanifest.com/Manifest.js';

var useManifestBridge$8 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  var status = usehooksTs.useScript(MANIFEST_SCRIPT);
  react.useEffect(function () {
    console.log({
      status: status
    });
    if (status === "loading") return;
    if (status === "error") {
      console.error("Error loading Manifest");
      return;
    }
    if (status === "ready" && !window.Manifest) {
      console.error("Error loading Manifest");
    }
  }, [status]);
  react.useEffect(function () {
    console.log({
      config: config
    });
    if (window.Manifest) {
      var manifestObj = window.Manifest.create(config);
      setManifest(manifestObj);
    }
  }, [config]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useExtractHooks = function () {
  return {
    message: "another mock hooks - fixes trial"
  };
};

var useScript = function (url) {
  react.useEffect(function () {
    var script = document.createElement("script");
    script.src = url;
    script.async = true;
    document.body.appendChild(script);
    return function () {
      document.body.removeChild(script);
    };
  }, [url]);
};

var useManifestBridge$7 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  var _b = react.useState(false),
    scriptLoaded = _b[0],
    setScriptLoaded = _b[1];
  react.useEffect(function () {
    var script = document.createElement("script");
    script.src = MANIFEST_SCRIPT;
    script.async = true;
    script.id = "manifest-bridge-script";
    document.body.appendChild(script);
    setScriptLoaded(true);
    return function () {
      document.body.removeChild(script);
    };
  }, []);
  var loadManifest = react.useCallback(function (configuration) {
    console.log("load Manifest callback");
    console.log(window.Manifest);
    if (window.Manifest) {
      console.log(window.Manifest);
      var manifestObj = window.Manifest.create(configuration);
      setManifest(manifestObj);
    }
  }, []);
  react.useEffect(function () {
    console.log({
      scriptLoaded: scriptLoaded
    });
    if (!scriptLoaded) return;
    console.log(window.document.getElementById("manifest-bridge-script"));
    loadManifest(config);
  }, [loadManifest, config, scriptLoaded]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge$6 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  var _b = react.useState(false),
    scriptLoaded = _b[0],
    setScriptLoaded = _b[1];
  react.useEffect(function () {
    var script = document.createElement("script");
    script.src = MANIFEST_SCRIPT;
    script.async = false;
    script.id = "manifest-bridge-script";
    document.body.appendChild(script);
    setTimeout(function () {
      return setScriptLoaded(true);
    }, 100);
    return function () {
      document.body.removeChild(script);
    };
  }, []);
  var loadManifest = react.useCallback(function (configuration) {
    console.log("load Manifest callback");
    console.log(window.Manifest);
    if (window.Manifest) {
      console.log(window.Manifest);
      var manifestObj = window.Manifest.create(configuration);
      setManifest(manifestObj);
    }
  }, []);
  react.useEffect(function () {
    console.log({
      scriptLoaded: scriptLoaded
    });
    if (!scriptLoaded) return;
    loadManifest(config);
  }, [loadManifest, config, scriptLoaded]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge$5 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    var script = document.createElement("script");
    script.src = MANIFEST_SCRIPT;
    script.async = true;
    script.id = "manifest-bridge-script";
    document.body.appendChild(script);
    script.addEventListener("load", function () {
      console.log("script loaded");
      console.log(window.Manifest);
      if (window.Manifest) {
        console.log(window.Manifest);
        var manifestObj = window.Manifest.create(config);
        setManifest(manifestObj);
      }
    });
    return function () {
      document.body.removeChild(script);
      script.removeEventListener("load", function () {});
    };
  }, []);
  react.useEffect(function () {
    if (window.Manifest) {
      console.log(window.Manifest);
      var manifestObj = window.Manifest.create(config);
      setManifest(manifestObj);
    }
  }, [config]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge$4 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    console.log({
      config: config
    });
    var checkScriptExisted = document.getElementById("manifest-bridge-script");
    console.log({
      checkScriptExisted: checkScriptExisted
    });
    var script = document.createElement("script");
    script.src = MANIFEST_SCRIPT;
    script.async = true;
    script.id = "manifest-bridge-script";
    document.body.appendChild(script);
    script.addEventListener("load", function () {
      console.log("script loaded");
      console.log(window.Manifest);
      if (window.Manifest) {
        console.log(window.Manifest);
        var manifestObj = window.Manifest.create(config);
        setManifest(manifestObj);
      }
    });
    return function () {
      document.body.removeChild(script);
      script.removeEventListener("load", function () {});
    };
  }, [config]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */
var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
  var e = new Error(message);
  return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

var useManifestBridge$3 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    console.log({
      config: config
    });
    var checkScriptExisted = document.getElementById("manifest-bridge-script");
    console.log({
      checkScriptExisted: checkScriptExisted
    });
    if (!checkScriptExisted) {
      var script = document.createElement("script");
      script.src = MANIFEST_SCRIPT;
      script.async = true;
      script.id = "manifest-bridge-script";
      document.body.appendChild(script);
      script.addEventListener("load", function () {
        console.log("script loaded");
        console.log(window.Manifest);
        if (window.Manifest) {
          var manifestObj = window.Manifest.create(__assign({}, config));
          setManifest(manifestObj);
        }
      });
    } else {
      console.log("script already loaded");
      if (window.Manifest) {
        var manifestObj = window.Manifest.create(__assign({}, config));
        setManifest(manifestObj);
      }
    }
  }, [config]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge$2 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    console.log({
      config: config
    });
    var checkScriptExisted = document.getElementById("manifest-bridge-script");
    console.log({
      checkScriptExisted: checkScriptExisted
    });
    if (!checkScriptExisted) {
      var script = document.createElement("script");
      script.src = MANIFEST_SCRIPT;
      script.async = true;
      script.id = "manifest-bridge-script";
      document.body.appendChild(script);
      script.addEventListener("load", function () {
        console.log("script loaded");
        console.log(window.Manifest);
        if (window.Manifest) {
          var manifestObj = window.Manifest.create(__assign({}, config));
          setManifest(manifestObj);
        }
      });
    }
  }, []);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge$1 = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    var checkScriptExisted = document.getElementById("manifest-bridge-script");
    console.log({
      checkScriptExisted: checkScriptExisted
    });
    if (!checkScriptExisted) {
      var script = document.createElement("script");
      script.src = MANIFEST_SCRIPT;
      script.async = true;
      script.id = "manifest-bridge-script";
      document.body.appendChild(script);
      script.addEventListener("load", function () {
        console.log("script loaded");
        console.log(window.Manifest);
        if (window.Manifest) {
          var manifestObj = window.Manifest.create(__assign({}, config));
          setManifest(manifestObj);
        }
      });
    } else {
      console.log("script already loaded");
      console.log({
        config: config
      });
      console.log(manifest);
    }
  }, [config]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

var useManifestBridge = function (config) {
  var _a = react.useState(),
    manifest = _a[0],
    setManifest = _a[1];
  react.useEffect(function () {
    console.log({
      config: config
    });
    var checkScriptExisted = document.getElementById("manifest-bridge-script");
    console.log({
      checkScriptExisted: checkScriptExisted
    });
    if (!checkScriptExisted) {
      var script = document.createElement("script");
      script.src = MANIFEST_SCRIPT;
      script.async = true;
      script.id = "manifest-bridge-script";
      document.body.appendChild(script);
      script.addEventListener("load", function () {
        console.log("script loaded");
        console.log(window.Manifest);
        if (window.Manifest) {
          var manifestObj = window.Manifest.create(__assign({}, config));
          setManifest(manifestObj);
        }
      });
    } else {
      console.log("script already loaded");
      if (window.Manifest) {
        var manifestObj = window.Manifest.create(__assign({}, config));
        setManifest(manifestObj);
      }
    }
  }, [config.accessToken, config.transferIntentReference, config.transferReference]);
  return {
    open: manifest ? manifest.open : function () {}
  };
};

exports.useExtractHooks = useExtractHooks;
exports.useLoadScript = useLoadScript;
exports.useManifestBridge = useManifestBridge$8;
exports.useManifestBridge2 = useManifestBridge$7;
exports.useManifestBridge3 = useManifestBridge$6;
exports.useManifestBridge4 = useManifestBridge$5;
exports.useManifestBridge5 = useManifestBridge$4;
exports.useManifestBridge6 = useManifestBridge$3;
exports.useManifestBridge7 = useManifestBridge$2;
exports.useManifestBridge8 = useManifestBridge$1;
exports.useManifestBridge9 = useManifestBridge;
exports.useScript = useScript;
